const config = require('../config/app.config.js');
const models = require('../models');
const User = models.user;
const Role = models.role;
var jwt = require('jsonwebtoken');
var bcrypt = require('bcryptjs');


exports.signup = (req, res) => {
    console.log("Processing func -> signup");
    User.create({
        name: req.body.name, 
        email: req.body.email,
        username: req.body.username,
        password: bcrypt.hashSync(req.body.password)
    }).then(user => {
        Role.findOne({
            where: {
                name: req.body.role
            }
        }).then(role => {
            user.setRole(role).then(() => {
                res.send("User registered successfully!");
            })
        }).catch(err => {
            res.status(500).send('Error -> ' + err);
        });
    }).catch(err => {
        res.status(500).send('Fail! Error -> ' + err);
    });
}

exports.signin = (req, res) => {
    console.log('Sign in');

    User.findOne({
        where: {
            username: req.body.username
        },
        include: [{
			model: Role, 
			attributes: ['name']
		}]
    }).then(user => {
        if(!user) {
            return res.status(404).send('User not found!');
        }

        var isPasswordValid = bcrypt.compareSync(req.body.password, user.password);
        if(!isPasswordValid) {
            return res.status(401).send({
                auth: false,
                accessToken: null,
                reason: "Invalid password!"
            });
        }

        var payload = {id: user.id, role: user.role.name};

        var token = jwt.sign(payload, config.secret, {
            expiresIn: config.jwtExpireTime
        });
        
        // access token pasang di cookies nanti!
        res.setHeader('Set-Cookie', "userToken="+token+"; HttpOnly; Path=/");
        res.status(200).send({
            auth: true,
            message: "User is successfully signed in!"
        });
        
    }).catch(err => {
        res.status(500).send('Error -> ' + err);
    });
}
