const verifySignUp = require('./verifySignUp');
const verifyJwtToken = require('./verifyJwtToken');
const tokenHandler = require('../controller/tokenController');

module.exports = function(app) {
    const authController = require('../controller/authController.js');
    const testController = require('../controller/testController.js');
    const userController = require('../controller/userController.js');
    app.post('/api/auth/signup', [verifySignUp.checkDuplicateUserNameOrEmail, verifySignUp.checkRolesExisted], authController.signup);
    app.post('/api/auth/login', authController.signin);

    app.get('/api/test/admin', [verifyJwtToken.verifyToken, 
                                verifyJwtToken.isAdmin, 
                                tokenHandler.extendJwtToken], testController.adminContent);
    app.get('/api/test/member', [verifyJwtToken.verifyToken, 
                                 tokenHandler.extendJwtToken], testController.memberContent);

    app.post('/api/user/all', [verifyJwtToken.verifyToken, verifyJwtToken.isAdmin], userController.fetchAll);
    app.post('/api/user/create', [verifyJwtToken.verifyToken, verifyJwtToken.isAdmin], userController.createUser);
    app.post('/api/user/edit', [verifyJwtToken.verifyToken, verifyJwtToken.isAdmin], userController.editUser);
    app.post('/api/user/delete', [verifyJwtToken.verifyToken, verifyJwtToken.isAdmin], userController.deleteUser);
    app.post('/api/user/detail', [verifyJwtToken.verifyToken, verifyJwtToken.isAdmin], userController.viewDetail);
}