process.NODE_ENV = "test";

let chai = require('chai')
let chaiHttp = require('chai-http')
const models = require('../models');
const User = models.user;
let app = require('../app.js')
let should = chai.should();
let expect = chai.expect;
var bcrypt = require('bcryptjs')

chai.use(chaiHttp);

describe('Users', () => {
    beforeEach((done) => {
        User.destroy({
            where: {},
            truncate: true
        });
        done();
    });
    describe('User Sign Up', ()=>{
        it('Sign user up', (done) =>{
            let user = {
                "name": "Komi Shouko",
                "username": "komisama",
                "email":"komi@gmail.com",
                "role":"Master Admin Diskominfo",
                "password":"komisama"
            };
            chai.request('http://127.0.0.1:8081')
                .post('/api/auth/signup')
                .send(user)
                .end((err, res)=>{
                    console.log(res.text);
                    should.exist(res);
                    res.should.have.status(200);
                    expect(res.text).to.equal('User registered successfully!');
                    done();
                });

        });
    });
});

describe("Create user", () => {
    it("Creating user", (done) => {
        User.findOne({
            where: {
                username:"komisama"
            },
            attributes: ['id']
        }).then(result => {
            console.log("Find done");
            let user = {
                "username":"komisama",
                "password":"komisama"
            };
            chai.request('http://127.0.0.1:8081')
                .post('/api/auth/login')
                .send(user)
                .then(res => {
                    console.log("sign done");
                    let req = {
                        "userId":result.id,
                        "name":"Udin",
                        "username":"udin",
                        "email":"udin@udin.com",
                        "password":"udin",
                        "role":"Master Admin Diskominfo"
                    };
                    console.log(req)
                    chai.request('http://127.0.0.1:8081')
                        .post('/api/user/create')
                        .set('x-access-token', res.body.accessToken)
                        .send(req)
                        .end((err, res)=>{
                            console.log(res.text);
                            should.exist(res);
                            res.should.have.status(200);
                            expect(res.text).to.equal('User created successfully!');
                            done();
                        });
                }).catch(err => {
                    res.status(500).send('Error -> ' + err);
                });
        }).catch(err => {
            res.status(500).send('Error -> ' + err);
        });
    });
});

describe("Fetch 'em All", () => {
    it('Fetch all user', (done) =>{
        User.findOne({
            where: {
                username:"komisama"
            },
            attributes: ['id']
        }).then(result => {
            console.log("Find done");
            let user = {
                "username":"komisama",
                "password":"komisama"
            };
            chai.request('http://127.0.0.1:8081')
                .post('/api/auth/login')
                .send(user)
                .then(res => {
                    console.log("sign done");
                    let req = {
                        "userId":result.id
                    };
                    console.log(req)
                    chai.request('http://127.0.0.1:8081')
                        .post('/api/user/all')
                        .set('x-access-token', res.body.accessToken)
                        .send(req)
                        .end((err, res)=>{
                            console.log(res.text);
                            should.exist(res);
                            res.should.have.status(200);
                            expect(res.body.users[1].name).to.equal('Komi Shouko');
                            expect(res.body.users[1].role.id).to.equal(1);
                            expect(res.body.users[1].role.name).to.equal("Master Admin Diskominfo");
                            done();
                    });
                }).catch(err => {
                    res.status(500).send('Error -> ' + err);
                });
        }).catch(err => {
            res.status(500).send('Error -> ' + err);
        });
    });
});

describe("Edit user", () => {
    it("Editing user", (done) => {
        User.findOne({
            where: {
                username:"komisama"
            },
            attributes: ['id']
        }).then(result => {
            console.log("Find done");
            let user = {
                "username":"komisama",
                "password":"komisama"
            };
            chai.request('http://127.0.0.1:8081')
                .post('/api/auth/login')
                .send(user)
                .then(res => {
                    console.log("sign done");
                    let req = {
                        "userId":result.id,
                        "id":result.id,
                        "name":"Di-Komix Aja",
                        "username":"komisama",
                        "email":"komix@yahoo.com",
                        "password":"komisama",
                        "role":"Master Admin Diskominfo"
                    };
                    console.log(req)
                    chai.request('http://127.0.0.1:8081')
                        .post('/api/user/edit')
                        .set('x-access-token', res.body.accessToken)
                        .send(req)
                        .end((err, res)=>{
                            console.log(res.text);
                            should.exist(res);
                            res.should.have.status(200);
                            expect(res.text).to.equal('User edited successfully!');
                            done();
                        });
                }).catch(err => {
                    res.status(500).send('Error -> ' + err);
                });
        }).catch(err => {
            res.status(500).send('Error -> ' + err);
        });
    });
});

describe("View detail", () => {
    it("Detail user", (done) => {
        User.findOne({
            where: {
                username:"komisama"
            },
            attributes: ['id']
        }).then(result => {
            console.log("Find done");
            let user = {
                "username":"komisama",
                "password":"komisama"
            };
            chai.request('http://127.0.0.1:8081')
                .post('/api/auth/login')
                .send(user)
                .then(res => {
                    console.log("sign done");
                    let req = {
                        "userId":result.id,
                        "id":result.id
                    };
                    console.log(req)
                    chai.request('http://127.0.0.1:8081')
                        .post('/api/user/detail')
                        .set('x-access-token', res.body.accessToken)
                        .send(req)
                        .end((err, res)=>{
                            console.log(res.text);
                            should.exist(res);
                            res.should.have.status(200);
                            expect(res.body.users.name).to.equal('Di-Komix Aja');
                            expect(res.body.users.email).to.equal('komix@yahoo.com');
                            expect(res.body.users.username).to.equal('komisama');
                            done();
                        });
                }).catch(err => {
                    res.status(500).send('Error -> ' + err);
                });
        }).catch(err => {
            res.status(500).send('Error -> ' + err);
        });
    });
});

describe("Delete User", () => {
    it("Delete user", (done) => {
        User.findOne({
            where: {
                username:"komisama"
            },
            attributes: ['id']
        }).then(result => {
            console.log("Find done");
            let user = {
                "username":"komisama",
                "password":"komisama"
            };
            chai.request('http://127.0.0.1:8081')
                .post('/api/auth/login')
                .send(user)
                .then(res => {
                    console.log("sign done");
                    let req = {
                        "userId":result.id,
                        "id":result.id
                    };
                    console.log(req)
                    chai.request('http://127.0.0.1:8081')
                        .post('/api/user/delete')
                        .set('x-access-token', res.body.accessToken)
                        .send(req)
                        .end((err, res)=>{
                            console.log(res.text);
                            should.exist(res);
                            res.should.have.status(200);
                            expect(res.text).to.equal('User deleted successfully!');
                            done();
                        });
                }).catch(err => {
                    res.status(500).send('Error -> ' + err);
                });
        }).catch(err => {
            res.status(500).send('Error -> ' + err);
        });
    });
});
